@@ -1,17 +1,17 @@
 import json
 
 
-def find(key, dictionary, path):
+def findpath(key, dictionary, path):
     for k, v in dictionary.items():
         if k == key:
             yield path + [k]
             # yield(path + [k])
         elif isinstance(v, dict):
-            for result in find(key, v, path + [k]):
+            for result in findpath(key, v, path + [k]):
                 yield result
         elif isinstance(v, list):
             for d in v:
-                for result in find(key, d, path + [k]):
+                for result in findpath(key, d, path + [k]):
                     yield result
 
 
@@ -22,4 +22,4 @@ def find(key, dictionary, path):
 with open('sample.json') as json_file:
     data = json.load(json_file)
 
-print(list(find('color', data, [])))
+# print(list(findpath('color', data, [])))
